@@ -1,4 +1,7 @@
 package Tapper::Schema::TestrunDB;
+BEGIN {
+  $Tapper::Schema::TestrunDB::AUTHORITY = 'cpan:AMD';
+}
 
 use 5.010;
 
@@ -7,7 +10,7 @@ use warnings;
 
 # Only increment this version here on schema changes.
 # For everything else increment Tapper/Schema.pm.
-our $VERSION = '3.000001';
+our $VERSION = '3.000005';
 
 # avoid these warnings
 #   Subroutine initialize redefined at /2home/ss5/perl510/lib/site_perl/5.10.0/Class/C3.pm line 70.
@@ -36,16 +39,6 @@ sub backup
         1;
 }
 
-=head2 _yaml_ok
-
-Check whether given string is valid yaml.
-
-@param string - yaml
-
-@return success - undef
-@return error   - error string
-
-=cut
 
 sub _yaml_ok {
         my ($condition) = @_;
@@ -59,3 +52,36 @@ sub _yaml_ok {
 
 1;
 
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Schema::TestrunDB
+
+=head2 _yaml_ok
+
+Check whether given string is valid yaml.
+
+@param string - yaml
+
+@return success - undef
+@return error   - error string
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
